@@ -1,4 +1,3 @@
-
 #pragma once
 
 #include "column.h"
@@ -11,6 +10,8 @@ namespace clickhouse {
  */
 class ColumnDecimal : public Column {
 public:
+    using ValueType = Int128;
+
     ColumnDecimal(size_t precision, size_t scale);
 
     void Append(const Int128& value);
@@ -20,11 +21,17 @@ public:
 
 public:
     void Append(ColumnRef column) override;
-    bool Load(CodedInputStream* input, size_t rows) override;
-    void Save(CodedOutputStream* output) override;
+    bool LoadBody(InputStream* input, size_t rows) override;
+    void SaveBody(OutputStream* output) override;
     void Clear() override;
     size_t Size() const override;
-    ColumnRef Slice(size_t begin, size_t len) override;
+    ColumnRef Slice(size_t begin, size_t len) const override;
+    ColumnRef CloneEmpty() const override;
+    void Swap(Column& other) override;
+    ItemView GetItem(size_t index) const override;
+
+    size_t GetScale() const;
+    size_t GetPrecision() const;
 
 private:
     /// Depending on a precision it can be one of:
@@ -33,7 +40,7 @@ private:
     ///  - ColumnInt128
     ColumnRef data_;
 
-    explicit ColumnDecimal(TypeRef type); // for `Slice(…)`
+    explicit ColumnDecimal(TypeRef type, ColumnRef data);
 };
 
 }
