@@ -16,13 +16,13 @@ ColumnIPv4::ColumnIPv4(ColumnRef data)
     , data_(data ? data->As<ColumnUInt32>() : nullptr)
 {
     if (!data_)
-        throw std::runtime_error("Expecting ColumnUInt32, got " + (data ? data->GetType().GetName() : "null"));
+        throw ValidationError("Expecting ColumnUInt32, got " + (data ? data->GetType().GetName() : "null"));
 }
 
 void ColumnIPv4::Append(const std::string& str) {
     uint32_t address;
     if (inet_pton(AF_INET, str.c_str(), &address) != 1)
-        throw std::runtime_error("invalid IPv4 format, ip: " + str);
+        throw ValidationError("invalid IPv4 format, ip: " + str);
     data_->Append(htonl(address));
 }
 
@@ -71,12 +71,12 @@ void ColumnIPv4::Append(ColumnRef column) {
     }
 }
 
-bool ColumnIPv4::Load(InputStream * input, size_t rows) {
-    return data_->Load(input, rows);
+bool ColumnIPv4::LoadBody(InputStream * input, size_t rows) {
+    return data_->LoadBody(input, rows);
 }
 
-void ColumnIPv4::Save(OutputStream* output) {
-    data_->Save(output);
+void ColumnIPv4::SaveBody(OutputStream* output) {
+    data_->SaveBody(output);
 }
 
 size_t ColumnIPv4::Size() const {
@@ -87,13 +87,17 @@ ColumnRef ColumnIPv4::Slice(size_t begin, size_t len) const {
     return std::make_shared<ColumnIPv4>(data_->Slice(begin, len));
 }
 
+ColumnRef ColumnIPv4::CloneEmpty() const {
+    return std::make_shared<ColumnIPv4>(data_->CloneEmpty());
+}
+
 void ColumnIPv4::Swap(Column& other) {
     auto & col = dynamic_cast<ColumnIPv4 &>(other);
     data_.swap(col.data_);
 }
 
 ItemView ColumnIPv4::GetItem(size_t index) const {
-    return data_->GetItem(index);
+    return ItemView(Type::IPv4, data_->GetItem(index));
 }
 
 }
