@@ -5,6 +5,7 @@
 #include "cpp.h"
 
 #include "MySQL_Protocol.h"
+#include "proxy_protocol_info.h"
 
 #ifndef uchar
 typedef unsigned char uchar;
@@ -140,6 +141,7 @@ class MySQL_Data_Stream
 		char *addr;
 		int port;
 	} proxy_addr;
+	ProxyProtocolInfo * PROXY_info;
 
 	unsigned int connect_tries;
 	int query_retries_on_failure;
