@@ -478,6 +478,7 @@ class MySQL_Threads_Handler
 		bool parse_failure_logs_digest;
 		bool default_reconnect;
 		bool have_compress;
+		int protocol_compression_level;
 		bool have_ssl;
 		bool multiplexing;
 //		bool stmt_multiplexing;
@@ -535,6 +536,9 @@ class MySQL_Threads_Handler
 		int connpoll_reset_queue_length;
 		char *eventslog_filename;
 		int eventslog_filesize;
+		int eventslog_buffer_history_size;
+		int eventslog_table_memory_size;
+		int eventslog_buffer_max_query_length;
 		int eventslog_default_log;
 		int eventslog_format;
 		char *auditlog_filename;
