@@ -11,9 +11,9 @@ class ProxySQL_HTTP_Server {
 	time_t cur_time;
 	pthread_mutex_t check_version_mutex;
 	time_t last_check_version;
-	std::string * generate_header(char *);
-	std::string * generate_canvas(char *);
-	std::string * generate_chart(char *chart_name, char *ts, int nsets, char **dname, char **llabel, char **values);
+	std::string generate_header(char *);
+	std::string generate_canvas(char *);
+	std::string generate_chart(char *chart_name, char *ts, int nsets, char **dname, char **llabel, char **values);
 	char *extract_values(SQLite3_result *result, int idx, bool relative, double mult=1);
 	char *extract_ts(SQLite3_result *result, bool relative);
 	public:
