@@ -19,6 +19,10 @@
 */
 
 #include "httpserver/basic_auth_fail_response.hpp"
+#include <microhttpd.h>
+
+struct MHD_Connection;
+struct MHD_Response;
 
 using namespace std;
 
