@@ -142,6 +142,8 @@ get_sources(){
     git checkout ${PROXYSQL_BRANCH}
     GIT_VERSION=${VERSION}-percona
     REVISION=$(git rev-parse --short HEAD)
+    sed -i "s|^GIT_VERSION ?= .*|GIT_VERSION=${VERSION}-percona|" Makefile
+    sed -i '0,/^endif$/s/^endif$/endif\nexport GIT_VERSION := $(GIT_VERSION)/' Makefile
     sed -i "s/export CURVER?=.*/export CURVER?=${VERSION}/g" Makefile
     sed -i 's/shell cat.*/shell rpm --eval \%rhel)/' deps/Makefile
     sed -i 's:6.7:6:' deps/Makefile
@@ -162,7 +164,7 @@ get_sources(){
     source proxysql.properties
     #
 
-    tar --owner=0 --group=0 -czf ${PRODUCT_FULL}.tar.gz ${PRODUCT_FULL}
+    tar --owner=0 --group=0 --exclude=.git -czf ${PRODUCT_FULL}.tar.gz ${PRODUCT_FULL}
     echo "UPLOAD=UPLOAD/experimental/BUILDS/${PRODUCT}/${PRODUCT_FULL}/${PSM_BRANCH}/${REVISION}/${BUILD_ID}" >> proxysql.properties
     mkdir $WORKDIR/source_tarball
     mkdir $CURDIR/source_tarball
@@ -190,18 +192,19 @@ get_system(){
 install_go() {
     export PATH=$PATH:/usr/bin/go/bin
     if [ x"$ARCH" = "xx86_64" ]; then
-        wget https://go.dev/dl/go1.22.7.linux-amd64.tar.gz
+        wget https://go.dev/dl/go1.23.12.linux-amd64.tar.gz
         rm -rf /usr/bin/go
-        tar -C /usr/bin -xzf go1.22.7.linux-amd64.tar.gz
+        tar -C /usr/bin -xzf go1.23.12.linux-amd64.tar.gz
         #update-alternatives --install /usr/bin/go go /usr/local/go/bin/go 1
         #update-alternatives --set go /usr/local/go/bin/go
     else
-        wget https://go.dev/dl/go1.22.7.linux-arm64.tar.gz
+        wget https://go.dev/dl/go1.23.12.linux-arm64.tar.gz
         rm -rf /usr/bin/go
-        tar -C /usr/bin -xzf go1.22.7.linux-arm64.tar.gz
+        tar -C /usr/bin -xzf go1.23.12.linux-arm64.tar.gz
         #update-alternatives --install /usr/bin/go go /usr/local/go/bin/go 1
         #update-alternatives --set go /usr/local/go/bin/go
     fi
+    export PATH=$PATH:/usr/bin/go/bin
     go version
     which go
     whereis go
@@ -242,7 +245,11 @@ install_deps() {
 #      wget http://jenkins.percona.com/yum-repo/percona-dev.repo
 #      mv -f percona-dev.repo /etc/yum.repos.d/
       yum clean all
-      yum -y install curl epel-release
+      if [ "x${RHEL}" = "x10" ]; then
+          yum -y install curl oracle-epel-release-el10
+      else
+          yum -y install curl epel-release
+      fi
       if [ "x${RHEL}" = "x7" -o "x${RHEL}" = "x8" ]; then
             switch_to_vault_repo
       fi
@@ -285,7 +292,7 @@ install_deps() {
      #   fi
       fi
      # yum -y install docbook-xsl libxslt-devel
-      INSTALL_LIST="git wget epel-release rpm-build gcc perl automake bzip2 cmake make gcc-c++ gcc git openssl openssl-devel gnutls gnutls-devel libtool patch python3 perl-IPC-Cmd libuuid-devel"
+      INSTALL_LIST="git wget rpm-build gcc perl automake bzip2 cmake make gcc-c++ gcc git openssl openssl-devel gnutls gnutls-devel libtool patch python3 perl-IPC-Cmd libuuid-devel"
       yum -y install ${INSTALL_LIST}
       install_go
       #update_pat
@@ -315,6 +322,16 @@ install_deps() {
           yum-config-manager --enable ol9_codeready_builder
           yum -y install epel-release
           yum -y install libcurl-devel libunwind libunwind-devel zlib-devel
+          yum -y install libicu-devel libevent-devel
+          yum -y install patchelf
+      fi
+      if [ $RHEL = 10 ]; then
+          yum -y install python3 gnutls-devel libtool || true
+          ln -s /usr/bin/python3.9 /usr/bin/python || true
+          yum-config-manager --enable ol10_codeready_builder
+          yum -y install libcurl-devel libunwind libunwind-devel zlib-devel
+          yum -y install libicu-devel libevent-devel
+          yum -y install patchelf
       fi
       if [ $RHEL -eq 7 ]; then
           /usr/bin/python -V
@@ -395,6 +412,7 @@ install_deps() {
       fi
       install_go
       #update_pat
+      apt-get install -y libicu-dev libevent-dev
     fi
     return;
 }
@@ -461,25 +479,7 @@ build_srpm(){
     tar vxzf ${WORKDIR}/${TARFILE} --wildcards '*/rpm' --strip=1
     #
     cp -av rpm/* rpmbuild/SOURCES
-    cd ${WORKDIR}/${PRODUCT_FULL}/proxysql-admin-tool
-    update_pat
-    cd $WORKDIR
-    cp -ap ${WORKDIR}/${PRODUCT_FULL}/proxysql-admin-tool/* rpmbuild/SOURCES/
-    cp -ap ${WORKDIR}/${PRODUCT_FULL}/proxysql-admin-tool/percona-scheduler/pxc_scheduler_handler rpmbuild/SOURCES/
-    cp -ap ${WORKDIR}/${PRODUCT_FULL}/proxysql-admin-tool/config.toml rpmbuild/SOURCES/
-    cd rpmbuild/SOURCES
-    
-   # wget --no-check-certificate https://download.osgeo.org/postgis/docs/postgis-3.3.1.pdf
-    #wget --no-check-certificate https://www.postgresql.org/files/documentation/pdf/12/postgresql-12-A4.pdf
-    cd ../../
     cp -av rpmbuild/SOURCES/proxysql.spec rpmbuild/SPECS
-#    cd ${WORKDIR}/rpmbuild/SPECS
-#    cp -ap ${WORKDIR}/proxysql-packaging/rpm/*.spec .
-#    cp -ap ${WORKDIR}/proxysql-admin-tool/* rpmbuild/SOURCES/
-#    cp -ap ${WORKDIR}/proxysql-admin-tool/percona-scheduler/pxc_scheduler_handler rpmbuild/SOURCES/
-#    cp -ap ${WORKDIR}/proxysql-admin-tool/config.toml rpmbuild/SOURCES/
-    cd ${WORKDIR}
-    #
     mv -fv ${TARFILE} ${WORKDIR}/rpmbuild/SOURCES
    # if [ -f /opt/rh/devtoolset-7/enable ]; then
    #     source /opt/rh/devtoolset-7/enable
@@ -528,9 +528,18 @@ build_rpm(){
     mkdir -vp rpmbuild/{SOURCES,SPECS,BUILD,SRPMS,RPMS}
     cp $SRC_RPM rpmbuild/SRPMS/
 
-    cd rpmbuild/SRPMS/
-    #
-    cd $WORKDIR
+    git clone ${PAT_REPO}
+    cd proxysql-admin-tool
+    git fetch origin
+    if [ ! -z ${PAT_TAG} ]; then
+        git checkout ${PAT_TAG}
+    fi
+    sed -i 's:2.0.12:2.0.15:' proxysql-admin
+    update_pat
+    cd ${WORKDIR}
+    cp -ap ${WORKDIR}/proxysql-admin-tool/* rpmbuild/SOURCES/
+    cp -ap ${WORKDIR}/proxysql-admin-tool/percona-scheduler/pxc_scheduler_handler rpmbuild/SOURCES/
+    cp -ap ${WORKDIR}/proxysql-admin-tool/config.toml rpmbuild/SOURCES/
     RHEL=$(rpm --eval %rhel)
     ARCH=$(echo $(uname -m) | sed -e 's:i686:i386:g')
     [ -f /opt/percona-devtoolset/enable ] && source /opt/percona-devtoolset/enable
@@ -569,15 +578,7 @@ build_source_deb(){
     #
     
     mv ${TARFILE} ${PRODUCT}_${VERSION}.orig.tar.gz
-    cd ${BUILDDIR}/proxysql-admin-tool
-    update_pat
-    cd ..
-    cp -ap proxysql-admin-tool/* tools/
-    cp -ap proxysql-admin-tool/percona-scheduler/pxc_scheduler_handler tools/
-    cp -ap proxysql-admin-tool/config.toml etc/
-    mv tools/LICENSE .
-    mv tools/proxysql-admin.cnf etc/ 
-    cd debian
+    cd ${BUILDDIR}/debian
     #rm -rf changelog
     sed -i "s:@@VERSION@@:${VERSION}:g" changelog
     sed -i "s:@@VERSION@@:${VERSION}:g" control
@@ -689,13 +690,19 @@ build_deb(){
     #
     dpkg-source -x ${DSC}
     #
-    cd ${PRODUCT}-${VERSION}
+    git clone ${PAT_REPO}
     cd proxysql-admin-tool
+    git fetch origin
+    if [ ! -z ${PAT_TAG} ]; then
+        git checkout ${PAT_TAG}
+    fi
+    sed -i 's:2.0.12:2.0.15:' proxysql-admin
     update_pat
-    cd ..
-    cp -ap proxysql-admin-tool/* tools/
-    cp -ap proxysql-admin-tool/percona-scheduler/pxc_scheduler_handler tools/
-    cp -ap proxysql-admin-tool/config.toml etc/
+    cd ${WORKDIR}
+    cd ${PRODUCT}-${VERSION}
+    cp -ap ${WORKDIR}/proxysql-admin-tool/* tools/
+    cp -ap ${WORKDIR}/proxysql-admin-tool/percona-scheduler/pxc_scheduler_handler tools/
+    cp -ap ${WORKDIR}/proxysql-admin-tool/config.toml etc/
     mv tools/LICENSE .
     mv tools/proxysql-admin.cnf etc/
     sed -i "s:@@VERSION@@:${VERSION}:g" debian/changelog
