@@ -23,7 +23,6 @@
 #include <resolv.h>
 #include <arpa/inet.h>
 #include <pthread.h>
-#include "SpookyV2.h"
 
 #include <fcntl.h>
 #include <sys/utsname.h>
@@ -45,25 +44,6 @@
 #endif // MSG_NOSIGNAL
 #endif // __APPLE__
 
-#define SAFE_SQLITE3_STEP(_stmt) do {\
-  do {\
-    rc=sqlite3_step(_stmt);\
-    if (rc!=SQLITE_DONE) {\
-      assert(rc==SQLITE_LOCKED);\
-      usleep(100);\
-    }\
-  } while (rc!=SQLITE_DONE);\
-} while (0)
-
-#define SAFE_SQLITE3_STEP2(_stmt) do {\
-        do {\
-                rc=sqlite3_step(_stmt);\
-                if (rc==SQLITE_LOCKED || rc==SQLITE_BUSY) {\
-                        usleep(100);\
-                }\
-        } while (rc==SQLITE_LOCKED || rc==SQLITE_BUSY);\
-} while (0)
-
 struct cpu_timer
 {
 	cpu_timer() {
