@@ -36,12 +36,6 @@ inline int fastrand() {
 	return (g_seed>>16)&0x7FFF;
 }
 
-inline unsigned long long monotonic_time() {
-	struct timespec ts;
-	clock_gettime(CLOCK_MONOTONIC, &ts);
-	return (((unsigned long long) ts.tv_sec) * 1000000) + (ts.tv_nsec / 1000);
-}
-
 #define NTHREADS 5
 #define NCONNS 6
 #define NPREP 15000
