@@ -13,7 +13,7 @@
 #include <stdio.h>
 #include <functional>
 
-#include <mysql.h>
+#include "mysql.h"
 
 #include "tap.h"
 #include "command_line.h"
