@@ -16,7 +16,7 @@
 #include <stdio.h>
 #include <unistd.h>
 
-#include <mysql.h>
+#include "mysql.h"
 
 #include "tap.h"
 #include "command_line.h"
