@@ -29,7 +29,7 @@
 #include <time.h>
 #include <iostream>
 
-#include <mysql.h>
+#include "mysql.h"
 
 #include "tap.h"
 #include "command_line.h"
