@@ -1,7 +1,7 @@
 #include <unistd.h>
 #include <stdlib.h>
 #include <stdio.h>
-#include <mysql.h>
+#include "mysql.h"
 #include <string.h>
 #include <string>
 #include <time.h>
