@@ -6,7 +6,7 @@
 #include <vector>
 #include <string>
 #include <sstream>
-#include <mysql.h>
+#include "mysql.h"
 
 #include "tap.h"
 #include "command_line.h"
