@@ -5,16 +5,18 @@
 #include <iostream>
 #include <random>
 
-#include <mysql.h>
-#include <mysql/mysqld_error.h>
+#include "mysql.h"
+#include "mysqld_error.h"
 
-#include <proxysql_utils.h>
+#include "proxysql_utils.h"
 
 #include "tap.h"
 #include "command_line.h"
 
 #include "json.hpp"
 
+#include "MySQL_Protocol.h"
+
 using namespace nlohmann;
 
 using std::string;
